@@ -72,7 +72,8 @@ labelLayer <- function(x, spdf, df, spdfid = NULL, dfid = NULL, txt,
   }
   
   words <- x[[txt]]
-  cc <- sf::st_coordinates(sf::st_centroid(x = x, of_largest_polygon = max(sf::st_is(sf::st_as_sf(x), "MULTIPOLYGON"))))
+  cc <- sf::st_coordinates(sf::st_centroid(x = sf::st_geometry(x), 
+                                           of_largest_polygon = max(sf::st_is(sf::st_as_sf(x), "MULTIPOLYGON"))))
   
   if (!overlap){
     x <- unlist(cc[,1])
